# Description

This borehole location optimizer was developed as part of the [GeoModel](https://geomodel.pl/) project. The goal is to enable operators of geothermal fields to make informed decisions on how to expand production of their geothermal fields.

# Guide

A detailed user's guide is contained in [guide.md](https://github.com/ISOR-Geothermal/GeoModel-Optimizer/blob/master/guide.md). 

# License

MIT license
